Miscellaneous Python utilities from HMS DBMI.

- hms-aws-env
  To show info about AWS accounts/environments defined in ~/.aws/config.

- hms-aws-ecs
  To show info about AWS ECS (Elastic Container Service) for current AWS account/environment.

- hms-config
  To manage local configuration.
